pub enum Error {
Http(Error),
Deserialize(DeserializeBodyError),
Validation(ValidationError),
CachePermissions(ChannelError),
}Expand description
An error occurred when trying to update the cache
Variants
Http(Error)
An error was returned by Twilight’s HTTP client while making the request
Deserialize(DeserializeBodyError)
An error was returned by Twilight’s HTTP client while deserializing the response
Validation(ValidationError)
An error was returned by Twilight while validating a request
CachePermissions(ChannelError)
An error was returned by Twilight while trying to get the permissions from the cache