pub enum PermissionsSource<'cache> {
Given(Permissions),
Cached {
cache: &'cache InMemoryCache,
current_user_id: Id<UserMarker>,
},
Request,
}Expand description
Specify how permissions are handled on WebhooksCache::update
Variants
Given(Permissions)
Use the given permissions
Cached
Use the cache to get permissions
Refer to Twilight’s docs to make sure the passed cache is valid
Fields

cache: &'cache InMemoryCacheThe cache to get the permissions from

current_user_id: Id<UserMarker>The bot’s ID
Request
Understand the permissions from the error-response of the API request
You may want to use this if you aren’t already using InMemoryCache’s
permission feature, since the overhead of avoidable requests is usually
lower than caching the permissions